import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import JobProject from '@/types/table/jobProject';
import { JobFileData } from '@/api/generated/jobFileController';
import { JobContentData } from '@/api/generated/jobContentController';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface JobProjectData extends JobProject {
  jobFile?: JobFileData;
  jobContent?: JobContentData;
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class JobProjectController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<JobProjectData>>(API_CONTEXT + '/app/jobProject/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<JobProjectData>(API_CONTEXT + '/app/jobProject/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/jobProject/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/jobProject/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/jobProject/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/jobProject/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/jobProject/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/jobProject/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/jobProject/deleteBatch', params, httpOptions);
  }
}
