import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import RestaurantAreaMenu from '@/types/table/restaurantAreaMenu';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface RestaurantAreaMenuData extends RestaurantAreaMenu {
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class RestaurantAreaMenuController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<RestaurantAreaMenuData>>(API_CONTEXT + '/app/restaurantAreaMenu/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<RestaurantAreaMenuData>(API_CONTEXT + '/app/restaurantAreaMenu/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/restaurantAreaMenu/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/restaurantAreaMenu/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/restaurantAreaMenu/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/restaurantAreaMenu/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/restaurantAreaMenu/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/restaurantAreaMenu/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/restaurantAreaMenu/deleteBatch', params, httpOptions);
  }
}
