import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import RestaurantFoodType from '@/types/table/restaurantFoodType';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface RestaurantFoodTypeData extends RestaurantFoodType {
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class RestaurantFoodTypeController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<RestaurantFoodTypeData>>(API_CONTEXT + '/app/restaurantFoodType/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<RestaurantFoodTypeData>(API_CONTEXT + '/app/restaurantFoodType/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/restaurantFoodType/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/restaurantFoodType/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/restaurantFoodType/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/restaurantFoodType/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/restaurantFoodType/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/restaurantFoodType/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/restaurantFoodType/deleteBatch', params, httpOptions);
  }
}
