import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import TourCarCategory from '@/types/table/tourCarCategory';
import { TourCarDriverData } from '@/api/generated/tourCarDriverController';
import { SysDeptData } from '@/api/generated/sysDeptController';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface TourCarCategoryData extends TourCarCategory {
  tourCarDriver?: TourCarDriverData;
  sysDept?: SysDeptData;
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class TourCarCategoryController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<TourCarCategoryData>>(API_CONTEXT + '/app/tourCarCategory/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarCategoryData>(API_CONTEXT + '/app/tourCarCategory/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/tourCarCategory/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/tourCarCategory/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/tourCarCategory/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarCategory/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarCategory/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarCategory/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarCategory/deleteBatch', params, httpOptions);
  }
  static existCarCategory(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarCategoryData>(API_CONTEXT + '/app/extra/existCarCategory', params, httpOptions);
  }
  static isAdmin(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarCategoryData>(API_CONTEXT + '/app/extra/isAdmin', params, httpOptions);
  }
  static verifyDriverInfo(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarCategoryData>(API_CONTEXT + '/app/extra/verifyDriverInfo', params, httpOptions);
  }
}
