import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import TourCarDriver from '@/types/table/tourCarDriver';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface TourCarDriverData extends TourCarDriver {
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class TourCarDriverController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<TourCarDriverData>>(API_CONTEXT + '/app/tourCarDriver/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarDriverData>(API_CONTEXT + '/app/tourCarDriver/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/tourCarDriver/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/tourCarDriver/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/tourCarDriver/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarDriver/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarDriver/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarDriver/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarDriver/deleteBatch', params, httpOptions);
  }
  static existDriver(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarDriverData>(API_CONTEXT + '/app/extra/existDriver', params, httpOptions);
  }
  static isAdmin(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarDriverData>(API_CONTEXT + '/app/extra/isAdmin', params, httpOptions);
  }
  static verifyDelCarInfo(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarDriverData>(API_CONTEXT + '/app/extra/verifyDelCarInfo', params, httpOptions);
  }
}
