import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import TourCarOrder from '@/types/table/tourCarOrder';
import { TourCarCategoryData } from '@/api/generated/tourCarCategoryController';
import { TourCarDriverData } from '@/api/generated/tourCarDriverController';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface TourCarOrderData extends TourCarOrder {
  tourCarCategory?: TourCarCategoryData;
  tourCarDriver?: TourCarDriverData;
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class TourCarOrderController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<TourCarOrderData>>(API_CONTEXT + '/app/tourCarOrder/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourCarOrderData>(API_CONTEXT + '/app/tourCarOrder/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/tourCarOrder/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/tourCarOrder/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/tourCarOrder/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarOrder/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarOrder/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarOrder/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourCarOrder/deleteBatch', params, httpOptions);
  }
}
