import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import TourHouseAdvisorRelation from '@/types/table/tourHouseAdvisorRelation';
import { TourHouseSaleInfoData } from '@/api/generated/tourHouseSaleInfoController';
import { TourHouseAdvisorInfoData } from '@/api/generated/tourHouseAdvisorInfoController';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface TourHouseAdvisorRelationData extends TourHouseAdvisorRelation {
  tourHouseSaleInfo?: TourHouseSaleInfoData;
  tourHouseAdvisorInfo?: TourHouseAdvisorInfoData;
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class TourHouseAdvisorRelationController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<TourHouseAdvisorRelationData>>(API_CONTEXT + '/app/tourHouseAdvisorRelation/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourHouseAdvisorRelationData>(API_CONTEXT + '/app/tourHouseAdvisorRelation/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/tourHouseAdvisorRelation/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/tourHouseAdvisorRelation/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/tourHouseAdvisorRelation/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseAdvisorRelation/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseAdvisorRelation/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseAdvisorRelation/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseAdvisorRelation/deleteBatch', params, httpOptions);
  }
}
