import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import TourHouseSaleInfo from '@/types/table/tourHouseSaleInfo';
import { TourHouseFilesData } from '@/api/generated/tourHouseFilesController';
import { TourHouseDevelopersTypeData } from '@/api/generated/tourHouseDevelopersTypeController';
import { TourHouseAdvisorInfoData } from '@/api/generated/tourHouseAdvisorInfoController';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface TourHouseSaleInfoData extends TourHouseSaleInfo {
  tourHouseFilesList?: TourHouseFilesData[];
  tourHouseDevelopersType?: TourHouseDevelopersTypeData;
  tourHouseAdvisorInfoList?: TourHouseAdvisorInfoData[];
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class TourHouseSaleInfoController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<TourHouseSaleInfoData>>(API_CONTEXT + '/app/tourHouseSaleInfo/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourHouseSaleInfoData>(API_CONTEXT + '/app/tourHouseSaleInfo/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/tourHouseSaleInfo/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/tourHouseSaleInfo/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/tourHouseSaleInfo/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/deleteBatch', params, httpOptions);
  }
  static listTourHouseAdvisorRelation(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/listTourHouseAdvisorRelation', params, httpOptions);
  }
  static listNotInTourHouseAdvisorRelation(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/listNotInTourHouseAdvisorRelation', params, httpOptions);
  }
  static addTourHouseAdvisorRelation(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/addTourHouseAdvisorRelation', params, httpOptions);
  }
  static deleteTourHouseAdvisorRelation(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/deleteTourHouseAdvisorRelation', params, httpOptions);
  }
  static deleteTourHouseAdvisorRelationList(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/deleteTourHouseAdvisorRelationList', params, httpOptions);
  }
  static updateTourHouseAdvisorRelation(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourHouseSaleInfo/updateTourHouseAdvisorRelation', params, httpOptions);
  }
  static viewTourHouseAdvisorRelation(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get(API_CONTEXT + '/app/tourHouseSaleInfo/viewTourHouseAdvisorRelation', params, httpOptions);
  }
}
