import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import TourImGroup from '@/types/table/tourImGroup';
import { TourImGroupInvitationData } from '@/api/generated/tourImGroupInvitationController';
import { TourImMemberData } from '@/api/generated/tourImMemberController';
import { TourImMessageData } from '@/api/generated/tourImMessageController';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface TourImGroupData extends TourImGroup {
  tourImGroupInvitationList?: TourImGroupInvitationData[];
  tourImMemberList?: TourImMemberData[];
  tourImMessageList?: TourImMessageData[];
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class TourImGroupController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<TourImGroupData>>(API_CONTEXT + '/app/tourImGroup/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourImGroupData>(API_CONTEXT + '/app/tourImGroup/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/tourImGroup/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/tourImGroup/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/tourImGroup/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourImGroup/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourImGroup/update', params, httpOptions);
  }

  static updateBan(params: ANY_OBJECT, httpOptions?: RequestOption){
    return super.post(API_CONTEXT + '/app/tourImGroup/updateBan', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourImGroup/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourImGroup/deleteBatch', params, httpOptions);
  }
}
