import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import TourUser from '@/types/table/tourUser';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface TourUserData extends TourUser {
  __cascade_add_temp_id__?: string | number | undefined;
}

export default class TourUserController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<TourUserData>>('/website/tour/user/list', params, httpOptions);
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourUserData>('/website/tour/user/view', params, httpOptions);
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download('/website/tour/user/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload('/website/tour/user/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl('/website/tour/user/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post('/website/tour/user/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post('/website/tour/user/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post('/website/tour/user/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post('/website/tour/user/deleteBatch', params, httpOptions);
  }
}
