import { BaseController } from '@/api/BaseController';
import { RequestOption } from '@/common/http/types';
import { ANY_OBJECT } from '@/types/generic';
import { TableData } from '@/common/types/table';
import { useUrlBuilder } from '@/common/hooks/useUrl';
import TourismProject from '@/types/table/tourismProject';
import { TourismFileData } from '@/api/generated/tourismFileController';
import { TourismContentData } from '@/api/generated/tourismContentController';
import { API_CONTEXT } from '../config';

const { buildGetUrl } = useUrlBuilder();

export interface TourismProjectData extends TourismProject {
  tourismFile?: TourismFileData;
  tourismContent?: TourismContentData;
  __cascade_add_temp_id__?: string | number | undefined;
}
export interface TourismDatePrice {
  // id
  id?: number | undefined;
  // 出发日期
  departureDate?: Array<Date> | undefined;
  // 成人价格
  adultPrice?: number | undefined;
  // 儿童价格
  childrenPrice?: number | undefined;
}

export default class TourismProjectController extends BaseController {
  static list(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post<TableData<TourismProjectData>>(
      API_CONTEXT + '/app/tourismProject/list',
      params,
      httpOptions,
    );
  }
  static view(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourismProjectData>(
      API_CONTEXT + '/app/tourismProject/view',
      params,
      httpOptions,
    );
  }
  static export(params: ANY_OBJECT, fileName: string) {
    return super.download(API_CONTEXT + '/app/tourismProject/export', params, fileName);
  }
  static import(params: ANY_OBJECT) {
    return super.upload(API_CONTEXT + '/app/tourismProject/import', params);
  }
  static printUrl(params: ANY_OBJECT) {
    return buildGetUrl(API_CONTEXT + '/app/tourismProject/print', params);
  }
  static add(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourismProject/add', params, httpOptions);
  }
  static update(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourismProject/update', params, httpOptions);
  }
  static delete(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourismProject/delete', params, httpOptions);
  }
  static deleteBatch(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/tourismProject/deleteBatch', params, httpOptions);
  }
  static viewDatePrice(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.get<TourismDatePrice>(
      API_CONTEXT + '/app/extra/viewDatePrice',
      params,
      httpOptions,
    );
  }
  static updateDatePrice(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/extra/saveDatePrice', params, httpOptions);
  }
  static updateProjectState(params: ANY_OBJECT, httpOptions?: RequestOption) {
    return super.post(API_CONTEXT + '/app/extra/updateProjectState', params, httpOptions);
  }
}
